@@ -29,7 +29,7 @@
 #include "touchpad.h"
 
 typedef KGenericFactory<KSynaptics, QWidget> KSynapticsFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_ksynaptics, KSynapticsFactory("kcm_ksynaptics"))
+K_EXPORT_COMPONENT_FACTORY( kcm_ksynaptics, KSynapticsFactory( "ksynaptics" ))
 
 //! for initializing on KDE start-up
 extern "C" 
@@ -37,17 +37,18 @@ extern "C"
     KCModule *init_UserSettings(QWidget *, const char *)
     {
         // do initialization here
-	    TouchPad::applyConfig();
+	TouchPad::applyConfig();
 
         // ready :)
         return NULL;
-    };
+    }
 }
 
-
 KSynaptics::KSynaptics(QWidget *parent, const char *name, const QStringList&)
     : KCModule(KSynapticsFactory::instance(), parent, name)
 {
+  KLocale::setMainCatalogue( "ksynaptics" );
+  
   // place widgets here
   QBoxLayout * l = new QHBoxLayout(this);
 
@@ -56,20 +57,20 @@ KSynaptics::KSynaptics(QWidget *parent, const char *name, const QStringList&)
 
   connect( m_widget, SIGNAL( changed() ), SLOT( changed() ) );
 
-  m_aboutData = new KAboutData(I18N_NOOP("ksynaptics"), 
-      I18N_NOOP("setting up the synaptics touch pad"),
-      "0.2", I18N_NOOP("This kcmodule is based on the X11 Synaptics Driver"
-      " (http://w1.894.telia.com/~u89404340/touchpad/)"),
+  m_aboutData = new KAboutData( I18N_NOOP( "ksynaptics" ), 
+      I18N_NOOP( "setting up the synaptics touch pad" ),
+      I18N_NOOP( "0.2.3" ), I18N_NOOP( "This kcmodule is based on the X11 Synaptics Driver"
+      " (http://w1.894.telia.com/~u89404340/touchpad/)" ),
       KAboutData::License_GPL, "(c) 2004 by Stefan Kombrink",
-      0,"http://qsynaptics.sourceforge.net");
+      0, "http://qsynaptics.sourceforge.net" );
 
-  m_aboutData->addAuthor("Stefan Kombrink",
-      "http://qsynaptics.sourceforge.net", "katakombi@web.de");
-  m_aboutData->addAuthor( "Nadeem Hasan", QString::null, "nhasan@kde.org" );
-  // <--delete me  m_aboutData->addAuthor( "Andrea Dieni", QString::null, "andrea.dieni@aliceposta.it" );
+  m_aboutData->addAuthor( "Stefan Kombrink", 0, "katakombi@web.de",
+                          "http://qsynaptics.sourceforge.net");
+  m_aboutData->addAuthor( "Nadeem Hasan", 0, "nhasan@kde.org" );
+  m_aboutData->addAuthor( "Andrea Dieni", 0, "andrea.dieni@aliceposta.it" );
 
   load();
-};
+}
 
 KSynaptics::~KSynaptics()
 {
