@@ -19,8 +19,8 @@
  ***************************************************************************/
  
 
-#ifndef __SYNPARAM_H
-#define __SYNPARAM_H
+#ifndef SYNPARAM_H
+#define SYNPARAM_H
 
 //
 // some TP parameters to begin with
